==> jc-1.4.0.tar.gz: gnu/xml/dom/JAXPFactory.h <==
// public final class gnu.xml.dom.JAXPFactory

// class file dependencies
// @dep_class 5d39546145be6ee4 gnu_xml_dom_JAXPFactory
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2ac95ce8b4614a01 javax_xml_parsers_DocumentBuilderFactory

// header file dependencies
// @dep_header javax_xml_parsers_DocumentBuilderFactory

#include "javax/xml/parsers/DocumentBuilderFactory.h"

#ifndef _JC_gnu_xml_dom_JAXPFactory_H_
#define _JC_gnu_xml_dom_JAXPFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_parsers_DocumentBuilder$object;
struct _jc_javax_xml_parsers_SAXParserFactory$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_JAXPFactory$sub_refs	_jc_gnu_xml_dom_JAXPFactory$sub_refs;
typedef struct _jc_gnu_xml_dom_JAXPFactory$sub_nonrefs	_jc_gnu_xml_dom_JAXPFactory$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_JAXPFactory$refs	_jc_gnu_xml_dom_JAXPFactory$refs;
typedef struct _jc_gnu_xml_dom_JAXPFactory$nonrefs	_jc_gnu_xml_dom_JAXPFactory$nonrefs;
typedef struct _jc_gnu_xml_dom_JAXPFactory$object	_jc_gnu_xml_dom_JAXPFactory$object;

typedef struct _jc_gnu_xml_dom_JAXPFactory$fields_struct	_jc_gnu_xml_dom_JAXPFactory$fields_struct;
typedef const struct _jc_gnu_xml_dom_JAXPFactory$vmethods	_jc_gnu_xml_dom_JAXPFactory$vmethods;
typedef const struct _jc_gnu_xml_dom_JAXPFactory$vtable	_jc_gnu_xml_dom_JAXPFactory$vtable;
typedef const struct _jc_gnu_xml_dom_JAXPFactory$vtype	_jc_gnu_xml_dom_JAXPFactory$vtype;

// Class fields structure
struct _jc_gnu_xml_dom_JAXPFactory$fields_struct {
	struct _jc_java_lang_String$object	*FEATURE;
	struct _jc_java_lang_String$object	*PROPERTY;
};
extern _jc_gnu_xml_dom_JAXPFactory$fields_struct _jc_gnu_xml_dom_JAXPFactory$class_fields;

// Constructors
extern void _jc_gnu_xml_dom_JAXPFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_dom_JAXPFactory$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_dom_JAXPFactory$method$getAttribute$bd4ba72dbd34d711(_jc_env *, struct _jc_gnu_xml_dom_JAXPFactory$object *, struct _jc_java_lang_String$object *);
extern struct _jc_javax_xml_parsers_DocumentBuilder$object *_jc_gnu_xml_dom_JAXPFactory$method$newDocumentBuilder$e5d58fd72aab1990(_jc_env *, struct _jc_gnu_xml_dom_JAXPFactory$object *);
extern void _jc_gnu_xml_dom_JAXPFactory$method$setAttribute$f7af18cb25a05ce1(_jc_env *, struct _jc_gnu_xml_dom_JAXPFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_JAXPFactory$method_info$getAttribute$bd4ba72dbd34d711;
extern _jc_method _jc_gnu_xml_dom_JAXPFactory$method_info$newDocumentBuilder$e5d58fd72aab1990;
extern _jc_method _jc_gnu_xml_dom_JAXPFactory$method_info$setAttribute$f7af18cb25a05ce1;

// Static methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_JAXPFactory$method$access__240$d960b0a055e8d9a6(_jc_env *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_JAXPFactory$method$access__241$84d0732ef998676e(_jc_env *);

// Virtual methods structure
struct _jc_gnu_xml_dom_JAXPFactory$vmethods {
	struct _jc_java_lang_Object$object	*(*getAttribute$bd4ba72dbd34d711)(_jc_env *, struct _jc_gnu_xml_dom_JAXPFactory$object *, struct _jc_java_lang_String$object *);
	struct _jc_javax_xml_parsers_DocumentBuilder$object	*(*newDocumentBuilder$e5d58fd72aab1990)(_jc_env *, struct _jc_gnu_xml_dom_JAXPFactory$object *);
	void	(*setAttribute$f7af18cb25a05ce1)(_jc_env *, struct _jc_gnu_xml_dom_JAXPFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_gnu_xml_dom_JAXPFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_parsers_DocumentBuilderFactory$vmethods	javax_xml_parsers_DocumentBuilderFactory;
	_jc_gnu_xml_dom_JAXPFactory$vmethods	gnu_xml_dom_JAXPFactory;
};

// Vtype
struct _jc_gnu_xml_dom_JAXPFactory$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_JAXPFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_JAXPFactory$sub_refs {
	struct _jc_javax_xml_parsers_SAXParserFactory$object	*pf;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_JAXPFactory$refs {
    _jc_gnu_xml_dom_JAXPFactory$sub_refs	gnu_xml_dom_JAXPFactory;
    _jc_javax_xml_parsers_DocumentBuilderFactory$sub_refs	javax_xml_parsers_DocumentBuilderFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_JAXPFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_JAXPFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_parsers_DocumentBuilderFactory$sub_nonrefs	javax_xml_parsers_DocumentBuilderFactory;
    _jc_gnu_xml_dom_JAXPFactory$sub_nonrefs	gnu_xml_dom_JAXPFactory;
};

// Object instance structure
struct _jc_gnu_xml_dom_JAXPFactory$object {
	_jc_gnu_xml_dom_JAXPFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_JAXPFactory$vtype	*vtype;
	_jc_gnu_xml_dom_JAXPFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_JAXPFactory$vtype _jc_gnu_xml_dom_JAXPFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_JAXPFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_JAXPFactory$class_object;

#endif	/* _JC_gnu_xml_dom_JAXPFactory_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/dom/JAXPFactory.h <==
// public final class gnu.xml.dom.JAXPFactory

// class file dependencies
// @dep_class 5d39546145be6ee4 gnu_xml_dom_JAXPFactory
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2ac95ce8b4614a01 javax_xml_parsers_DocumentBuilderFactory

// header file dependencies
// @dep_header javax_xml_parsers_DocumentBuilderFactory

#include "javax/xml/parsers/DocumentBuilderFactory.h"

#ifndef _JC_gnu_xml_dom_JAXPFactory_H_
#define _JC_gnu_xml_dom_JAXPFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_parsers_DocumentBuilder$object;
struct _jc_javax_xml_parsers_SAXParserFactory$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_JAXPFactory$sub_refs	_jc_gnu_xml_dom_JAXPFactory$sub_refs;
typedef struct _jc_gnu_xml_dom_JAXPFactory$sub_nonrefs	_jc_gnu_xml_dom_JAXPFactory$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_JAXPFactory$refs	_jc_gnu_xml_dom_JAXPFactory$refs;
typedef struct _jc_gnu_xml_dom_JAXPFactory$nonrefs	_jc_gnu_xml_dom_JAXPFactory$nonrefs;
typedef struct _jc_gnu_xml_dom_JAXPFactory$object	_jc_gnu_xml_dom_JAXPFactory$object;

typedef struct _jc_gnu_xml_dom_JAXPFactory$fields_struct	_jc_gnu_xml_dom_JAXPFactory$fields_struct;
typedef const struct _jc_gnu_xml_dom_JAXPFactory$vmethods	_jc_gnu_xml_dom_JAXPFactory$vmethods;
typedef const struct _jc_gnu_xml_dom_JAXPFactory$vtable	_jc_gnu_xml_dom_JAXPFactory$vtable;
typedef const struct _jc_gnu_xml_dom_JAXPFactory$vtype	_jc_gnu_xml_dom_JAXPFactory$vtype;

// Class fields structure
struct _jc_gnu_xml_dom_JAXPFactory$fields_struct {
	struct _jc_java_lang_String$object	*FEATURE;
	struct _jc_java_lang_String$object	*PROPERTY;
};
extern _jc_gnu_xml_dom_JAXPFactory$fields_struct _jc_gnu_xml_dom_JAXPFactory$class_fields;

// Constructors
extern void _jc_gnu_xml_dom_JAXPFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_dom_JAXPFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_dom_JAXPFactory$method$getAttribute$bd4ba72dbd34d711(_jc_env *, struct _jc_gnu_xml_dom_JAXPFactory$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_xml_parsers_DocumentBuilder$object *_jc_gnu_xml_dom_JAXPFactory$method$newDocumentBuilder$e5d58fd72aab1990(_jc_env *, struct _jc_gnu_xml_dom_JAXPFactory$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_dom_JAXPFactory$method$setAttribute$f7af18cb25a05ce1(_jc_env *, struct _jc_gnu_xml_dom_JAXPFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_JAXPFactory$method_info$getAttribute$bd4ba72dbd34d711;
extern _jc_method _jc_gnu_xml_dom_JAXPFactory$method_info$newDocumentBuilder$e5d58fd72aab1990;
extern _jc_method _jc_gnu_xml_dom_JAXPFactory$method_info$setAttribute$f7af18cb25a05ce1;

// Static methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_JAXPFactory$method$access__240$d960b0a055e8d9a6(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_JAXPFactory$method$access__241$84d0732ef998676e(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_dom_JAXPFactory$vmethods {
	struct _jc_java_lang_Object$object	*(*getAttribute$bd4ba72dbd34d711)(_jc_env *, struct _jc_gnu_xml_dom_JAXPFactory$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_javax_xml_parsers_DocumentBuilder$object	*(*newDocumentBuilder$e5d58fd72aab1990)(_jc_env *, struct _jc_gnu_xml_dom_JAXPFactory$object *) _JC_JCNI_ATTR;
	void	(*setAttribute$f7af18cb25a05ce1)(_jc_env *, struct _jc_gnu_xml_dom_JAXPFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_JAXPFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_parsers_DocumentBuilderFactory$vmethods	javax_xml_parsers_DocumentBuilderFactory;
	_jc_gnu_xml_dom_JAXPFactory$vmethods	gnu_xml_dom_JAXPFactory;
};

// Vtype
struct _jc_gnu_xml_dom_JAXPFactory$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_JAXPFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_JAXPFactory$sub_refs {
	struct _jc_javax_xml_parsers_SAXParserFactory$object	*pf;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_JAXPFactory$refs {
    _jc_gnu_xml_dom_JAXPFactory$sub_refs	gnu_xml_dom_JAXPFactory;
    _jc_javax_xml_parsers_DocumentBuilderFactory$sub_refs	javax_xml_parsers_DocumentBuilderFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_JAXPFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_JAXPFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_parsers_DocumentBuilderFactory$sub_nonrefs	javax_xml_parsers_DocumentBuilderFactory;
    _jc_gnu_xml_dom_JAXPFactory$sub_nonrefs	gnu_xml_dom_JAXPFactory;
};

// Object instance structure
struct _jc_gnu_xml_dom_JAXPFactory$object {
	_jc_gnu_xml_dom_JAXPFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_JAXPFactory$vtype	*vtype;
	_jc_gnu_xml_dom_JAXPFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_JAXPFactory$vtype _jc_gnu_xml_dom_JAXPFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_JAXPFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_JAXPFactory$class_object;

#endif	/* _JC_gnu_xml_dom_JAXPFactory_H_ */
